# coding: utf-8

# flake8: noqa

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.5.0"

# import apis into sdk package
from aihub.api.queries_api import QueriesApi
from aihub.api.batches_api import BatchesApi
from aihub.api.conversations_api import ConversationsApi
from aihub.api.runs_api import RunsApi

# import ApiClient
from aihub.api_response import ApiResponse
from aihub.api_client import ApiClient
from aihub.configuration import Configuration
from aihub.exceptions import OpenApiException
from aihub.exceptions import ApiTypeError
from aihub.exceptions import ApiValueError
from aihub.exceptions import ApiKeyError
from aihub.exceptions import ApiAttributeError
from aihub.exceptions import ApiException

# import models into sdk package
from aihub.models.batch import Batch
from aihub.models.batch_deletion_job_response import BatchDeletionJobResponse
from aihub.models.batch_info import BatchInfo
from aihub.models.bounding_box import BoundingBox
from aihub.models.conversation import Conversation
from aihub.models.conversation_response import ConversationResponse
from aihub.models.conversation_response_upload_status import ConversationResponseUploadStatus
from aihub.models.conversation_response_upload_status_failure_inner import ConversationResponseUploadStatusFailureInner
from aihub.models.conversation_response_upload_status_success_inner import ConversationResponseUploadStatusSuccessInner
from aihub.models.conversation_summary import ConversationSummary
from aihub.models.converse_request import ConverseRequest
from aihub.models.create_batch_request import CreateBatchRequest
from aihub.models.document import Document
from aihub.models.document_details import DocumentDetails
from aihub.models.document_field import DocumentField
from aihub.models.document_field_confidence import DocumentFieldConfidence
from aihub.models.document_field_validations import DocumentFieldValidations
from aihub.models.document_field_validations_alerts_inner import DocumentFieldValidationsAlertsInner
from aihub.models.document_metadata_response import DocumentMetadataResponse
from aihub.models.document_upload_response import DocumentUploadResponse
from aihub.models.document_upload_response_upload_status import DocumentUploadResponseUploadStatus
from aihub.models.document_upload_response_upload_status_failure_inner import DocumentUploadResponseUploadStatusFailureInner
from aihub.models.document_upload_response_upload_status_success_inner import DocumentUploadResponseUploadStatusSuccessInner
from aihub.models.document_validations import DocumentValidations
from aihub.models.error import Error
from aihub.models.field_source_coordinates import FieldSourceCoordinates
from aihub.models.file_with_documents import FileWithDocuments
from aihub.models.job_status_response import JobStatusResponse
from aihub.models.list_batches200_response import ListBatches200Response
from aihub.models.list_conversations200_response import ListConversations200Response
from aihub.models.modification_object import ModificationObject
from aihub.models.modification_object_modifications_inner import ModificationObjectModificationsInner
from aihub.models.prompt_response import PromptResponse
from aihub.models.query_result import QueryResult
from aihub.models.query_status_response import QueryStatusResponse
from aihub.models.results_response import ResultsResponse
from aihub.models.run import Run
from aihub.models.run_app_request import RunAppRequest
from aihub.models.run_app_request_settings import RunAppRequestSettings
from aihub.models.run_app_request_settings_webhook_config import RunAppRequestSettingsWebhookConfig
from aihub.models.run_deployment_request import RunDeploymentRequest
from aihub.models.run_deployment_request_settings import RunDeploymentRequestSettings
from aihub.models.run_deployment_request_settings_webhook_config import RunDeploymentRequestSettingsWebhookConfig
from aihub.models.run_query_request import RunQueryRequest
from aihub.models.run_query_request_source_app import RunQueryRequestSourceApp
from aihub.models.run_query_response import RunQueryResponse
from aihub.models.source_document import SourceDocument
from aihub.models.source_page import SourcePage

from aihub.aihub import AIHub
